@@ -54,7 +54,7 @@ use Carp;
 
 use vars qw($VERSION $TABLE_COUNT $VIEW_COUNT);
 
-$VERSION = '1.60';
+$VERSION = '1.59';
 
 # ----------------------------------------------------------------------
 
@@ -244,9 +244,9 @@ sub action {
 
 =head2 action
 
-Gets or set the actions of the trigger.
+Gets or set the action of the trigger.
 
-  $trigger->actions(
+  $trigger->action(
       q[
         BEGIN
           select ...;
